@@ -1,4 +1,4 @@
-use async_std::{fs, path::PathBuf};
+use async_std::{fs, path::PathBuf, stream::{self, Stream}};
 use futures::StreamExt;
 
 pub struct StubFinder;
@@ -6,12 +6,12 @@ pub struct StubFinder;
 impl StubFinder {
     const JSON_EXTENSION: &'static str = "json";
 
-    pub async fn find_all_stubs(from: &PathBuf) -> Vec<PathBuf> {
+    pub async fn find_all_stubs(from: &PathBuf) -> impl Stream<Item=PathBuf> {
         if from.exists().await {
             if from.is_dir().await {
-                Self::find_all_stubs_under_dir(from).await
-            } else { vec![from.to_path_buf()] }
-        } else { vec![] }
+                stream::from_iter(Self::find_all_stubs_under_dir(from).await)
+            } else { stream::from_iter(vec![from.to_path_buf()]) }
+        } else { stream::from_iter(vec![]) }
     }
 
     async fn find_all_stubs_under_dir(from: &PathBuf) -> Vec<PathBuf> {
@@ -19,8 +19,7 @@ impl StubFinder {
         if let Ok(mut from) = fs::read_dir(from).await {
             while let Some(Ok(entry)) = from.next().await {
                 let path = entry.path();
-                let extension = path.extension().and_then(|it| it.to_str());
-                if path.is_file().await && extension == Some(Self::JSON_EXTENSION) {
+                if path.is_file().await && path.extension().and_then(|ext| ext.to_str()) == Some(Self::JSON_EXTENSION) {
                     stubs.push(path)
                 }
             }
@@ -39,7 +38,7 @@ mod stub_finder_test {
     #[async_std::test]
     async fn should_find_just_json_files_from_dir() {
         let from = PathBuf::from("tests/stubs/server");
-        let files = StubFinder::find_all_stubs(&from).await;
+        let files = StubFinder::find_all_stubs(&from).await.collect::<Vec<PathBuf>>().await;
         assert_eq!(files.len(), 2);
         let file_names = files.iter()
             .map(|it| it.file_name().unwrap().to_str().unwrap())
@@ -51,7 +50,7 @@ mod stub_finder_test {
     #[async_std::test]
     async fn should_find_all_files_from_single_file() {
         let from = PathBuf::from("tests/stubs/server/valid.json");
-        let files = StubFinder::find_all_stubs(&from).await;
+        let files = StubFinder::find_all_stubs(&from).await.collect::<Vec<PathBuf>>().await;
         assert_eq!(files.len(), 1);
         let file_names = files.iter()
             .map(|it| it.file_name().unwrap().to_str().unwrap())
@@ -62,10 +61,10 @@ mod stub_finder_test {
     #[async_std::test]
     async fn should_not_find_any_file_when_path_does_not_exist() {
         let from = PathBuf::from("tests/stubs/server/unknown");
-        let files = StubFinder::find_all_stubs(&from).await;
+        let files = StubFinder::find_all_stubs(&from).await.collect::<Vec<PathBuf>>().await;
         assert!(files.is_empty());
         let from = PathBuf::from("tests/stubs/server/unknown.json");
-        let files = StubFinder::find_all_stubs(&from).await;
+        let files = StubFinder::find_all_stubs(&from).await.collect::<Vec<PathBuf>>().await;
         assert!(files.is_empty());
     }
 
